# WalkMe Integration for SaaS Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#introduction)
  * [Implementation Details](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#implementation-details)
  * [Discovery Capabilities](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#discovery-capabilities)
  * [Setting up WalkMe Integration](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#setting-up-walkme-integration)
  * [Create an API Key In the Walkme Admin Center](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#create-an-api-key-in-the-walkme-admin-center)
  * [Enter the Copied Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#enter-the-copied-credentials-in-sap-leanix)
  * [Cross-Checking the Discovered Services](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery#cross-checking-the-discovered-services)


Configure the SAP LeanIX-WalkMe integration to automatically discover SaaS applications.
